# -*- coding: utf-8 -*-

# mapWOC
#
# Description: SQLAlchemy/ORM-Mapper for Results.
#
# Authors:
# Felix Wolfsteller <felix.wolfsteller@intevation.de>
#
# Copyright:
# Copyright (C) 2011 Bundesamt für Sicherheit in der Informationstechnik
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2,
# or, at your option, any later version as published by the Free
# Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

from sqlalchemy import Table, Column, ForeignKey, Integer, String, Text, DateTime
from sqlalchemy.orm import relationship, mapper

from mapwocgui.model.meta import Base, metadata

from mapwoc.lib.url import URL
import mapwoc.lib.model.url

from mapwoc.lib.result import Result, ResultType, Visit

# M:N Relational Table.
visit_result_table = Table('visit_result', metadata,
                    Column('visit_id', ForeignKey('visit.id')),
                    Column('result_id', Integer, ForeignKey('result.id')))

# Visit Table.
visit_table = Table('visit', metadata,
                    Column('id', Integer, primary_key=True),
                    Column('hc', String)
                    )

# Result Type Table.
result_type_table = Table('result_type', metadata,
                        Column('id', Integer, primary_key=True),
                        Column('type_name', String, nullable=False),
                        Column('severity', Integer))

# Result Table.
result_table = Table('result', metadata,
                  Column('id', Integer, primary_key=True),
                  Column('url_id', Integer, ForeignKey('url.id')),
                  Column('date', DateTime, nullable=False),
                  Column('dump_location',Text, nullable=True),
                  Column('result_type_id', Integer, ForeignKey('result_type.id')),
                  Column('text', Text),
                  Column('method', String))


# The Mappers
result_props = {'url':relationship(URL), 'result_type':relationship(ResultType)}
mapper(Result, result_table, properties=result_props)

visit_result_map_properties = {'results':relationship(Result,
                                             secondary=visit_result_table,
                                              backref='visit')}
mapper(Visit, visit_table, properties=visit_result_map_properties)
mapper(ResultType, result_type_table)

#TODO
# URL link doesnt work. maybe something like this: ?
#mapper(ScanConfiguration, scanconf_table, properties={
#       'urlcollection':relationship(URLList, secondary=scanconf_urllist),
#       'visitor_configuration':relationship(VisitorConfiguration,
#                                            uselist=False)})


